@@ -13,6 +13,7 @@ from ngr_spider.constants import (
     WFS_PROTOCOL,
     WMS_PROTOCOL,
     WMTS_PROTOCOL,
+    OAT_PROTOCOL,
 )
 from ngr_spider.csw_client import CSWClient
 from ngr_spider.decorators import asdict_minus_none
@@ -67,6 +68,7 @@ def main_services(args):
     no_updated = args.no_updated
     jq_filter = args.jq_filter
     log_level = args.log_level
+    no_filter = args.no_filter
     csw_url = args.csw_url
     setup_logger(log_level)
 
@@ -83,8 +85,8 @@ def main_services(args):
         cm = nullcontext()
     with cm:
         services = csw_client.get_csw_records_by_protocols(
-            protocol_list, svc_owner, number_records
-        )
+            protocol_list, svc_owner, number_records, no_filter
+        )  # TODO: refactor to match implementation here with in main_layers(), so no-filter can also be used on layers
 
         services_dict = [asdict_minus_none(x) for x in services]
 
@@ -145,10 +147,11 @@ def main_layers(args):
     no_updated = args.no_updated
     jq_filter = args.jq_filter
     log_level = args.log_level
+    csw_url = args.csw_url
     setup_logger(log_level)
     protocol_list = PROTOCOLS
 
-    csw_client = CSWClient(CSW_URL)
+    csw_client = CSWClient(csw_url)
 
     if protocols:
         protocol_list = protocols.split(",")
@@ -240,6 +243,7 @@ def main_layers(args):
         content = get_output(pretty, yaml_output, config, no_updated, jq_filter)
         write_output(output_file, az_conn_string, az_container, yaml_output, content)
         lookup = {
+            OAT_PROTOCOL: "layers",
             WMTS_PROTOCOL: "layers",
             WMS_PROTOCOL: "layers",
             WFS_PROTOCOL: "featuretypes",
@@ -378,6 +382,14 @@ def main():
         help="group services/layers by dataset and retrieve dataset metadata",
     )
 
+    services_parser.add_argument(
+        "--no-filter",
+        dest="no_filter",
+        action="store_true",
+        default=False,
+        help="Do not filter out services records with duplicate or empty service URLS",
+    )
+
     layers_parser = subparsers.add_parser(
         "layers", parents=[parent_parser], help="Generate list of all PDOK layers"
     )
