@@ -19,6 +19,7 @@ from owslib.wcs import WebCoverageService, wcs110  # type: ignore
 from owslib.wfs import WebFeatureService  # type: ignore
 from owslib.wms import WebMapService  # type: ignore
 from owslib.wmts import WebMapTileService
+from ngr_spider.ogc_api_tiles import OGCApiTiles
 
 from ngr_spider.constants import (  # type: ignore
     ATOM_PROTOCOL,
@@ -26,6 +27,7 @@ from ngr_spider.constants import (  # type: ignore
     WFS_PROTOCOL,
     WMS_PROTOCOL,
     WMTS_PROTOCOL,
+    OAT_PROTOCOL,
 )
 from ngr_spider.csw_client import CSWClient
 
@@ -43,6 +45,7 @@ from .models import (
     WmsService,
     WmtsLayer,
     WmtsService,
+    OatService,
 )
 
 LOGGER = logging.getLogger(__name__)
@@ -80,6 +83,7 @@ def write_output(output_file, az_conn_string, az_container, yaml_output, content
         sys.stdout.write(content)
     else:
         if az_conn_string and az_container:
+            LOGGER.info(f"write result to Azure Blob Storage")
             blob = BlobClient.from_connection_string(
                 conn_str=az_conn_string,
                 container_name=az_container,
@@ -95,6 +99,7 @@ def write_output(output_file, az_conn_string, az_container, yaml_output, content
                 overwrite=True,
             )
         else:
+            LOGGER.info(f"write result to local file system")
             with open(output_file, "w") as f:
                 f.write(content)
 
@@ -154,6 +159,8 @@ def get_service(service_record: CswServiceRecord) -> Union[Service, ServiceError
         service = get_wmts_service(service_record)
     elif protocol == ATOM_PROTOCOL:
         service = get_atom_service(service_record)
+    elif protocol == OAT_PROTOCOL:
+        service = get_oat_service(service_record)
     return service
 
 
@@ -258,6 +265,46 @@ def get_atom_service(
     return AtomService(service_record.service_url, r.text)
 
 
+def get_oat_service(
+    service_record: CswServiceRecord,
+) -> Union[OatService, ServiceError]:
+    try:
+        url = service_record.service_url
+        md_id = service_record.metadata_id
+        LOGGER.info(f"{md_id} - {url}")
+        if "://secure" in url:
+            # this is a secure layer not for the general public: ignore
+            return service_record
+        oat = OGCApiTiles(url)
+        title = oat.title
+        if title == "":  # fallback
+            title = empty_string_if_none(oat.service_desc.get_info().title)
+        description = oat.description
+        if description == "":  # fallback
+            description = empty_string_if_none(oat.service_desc.get_info().description)
+
+        layers = oat.get_layers()
+        for layer in layers:
+            layer.dataset_metadata_id = service_record.dataset_metadata_id
+
+        return OatService(
+            # http://docs.ogc.org/DRAFTS/19-072.html#rc_landing-page-section
+            title=title,
+            abstract=description,
+            metadata_id=md_id,
+            url=oat.service_desc.get_tile_request_url(),
+            layers=layers,
+            keywords=oat.service_desc.get_tags(),
+            dataset_metadata_id=service_record.dataset_metadata_id,
+        )
+    except requests.exceptions.HTTPError as e:
+        LOGGER.error(f"md-identifier: {md_id} - {e}")
+    except Exception:
+        message = f"unexpected error occured while retrieving cap doc, md-identifier {md_id}, url: {url}"
+        LOGGER.exception(message)
+    return ServiceError(service_record.service_url, service_record.metadata_id)
+
+
 def get_wms_service(
     service_record: CswServiceRecord,
 ) -> Union[WmsService, ServiceError]:
